@@ -54,7 +54,7 @@ class DropboxIE(InfoExtractor):
                 raise ExtractorError('Password protected video, use --video-password <password>', expected=True)
 
         info_json = self._search_json(r'InitReact\.mountComponent\(.*?,', webpage, 'mountComponent', video_id,
-                                      contains_pattern=r'.+?"preview".+?', end_pattern=r'\)')['props']
+                                      contains_pattern=r'{.+?"preview".+?}', end_pattern=r'\)')['props']
         transcode_url = traverse_obj(info_json, ((None, 'preview'), 'file', 'preview', 'content', 'transcode_url'), get_all=False)
         formats, subtitles = self._extract_m3u8_formats_and_subtitles(transcode_url, video_id)
 
