@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 from .common import InfoExtractor
 from ..compat import (
     compat_str,
@@ -96,7 +94,7 @@ class FlickrIE(InfoExtractor):
             owner = video_info.get('owner', {})
             uploader_id = owner.get('nsid')
             uploader_path = owner.get('path_alias') or uploader_id
-            uploader_url = format_field(uploader_path, template='https://www.flickr.com/photos/%s/')
+            uploader_url = format_field(uploader_path, None, 'https://www.flickr.com/photos/%s/')
 
             return {
                 'id': video_id,
